# Models

## Vault Models

::: aiobsidian.models.vault.FileStat

::: aiobsidian.models.vault.NoteJson

::: aiobsidian.models.vault.DocumentMap

::: aiobsidian.models.vault.VaultDirectory

## Search Models

::: aiobsidian.models.search.SearchMatch

::: aiobsidian.models.search.SearchResult

## System Models

::: aiobsidian.models.system.Versions

::: aiobsidian.models.system.ServerStatus

## Command Models

::: aiobsidian.models.commands.Command
